#!/bin/sh

if [ $# -ne 3 ] ; then 
  echo "illegal number of parameters, expecting low_res_file tiled_file output_dash_dir"
  exit 1
fi

base_file=$1
tile_file=$2
out_dir=$3
echo "base file: $base_file"
echo "tiled file: $tile_file"
echo "Ouput dir: $out_dir"


#create all MP4 MP4 files in src_mp4
generate_files ()
{

rm -rf $out_dir 2> /dev/null
mkdir $out_dir

rm -rf tiles_split 2> /dev/null
mkdir tiles_split

rm -rf src_mp4 2> /dev/null
mkdir src_mp4

MP4Box -raw 257 $base_file -out base
MP4Box -add base_pid257.264 -new src_mp4/live360_full_sphere_low_res.mp4
rm -f base_pid257.264

#extract all tiles
MP4Box -raw 257 $tile_file -out tiled
./tiles -x tiled_pid257.hvc tiles_split
rm -f tiled_pid257.hvc

#remux all tiles
for i in tiles_split/* ; do
name=$(basename ${i%.*})
MP4Box -add $i -new src_mp4/$name.mp4
done

}


generate_dash()
{
sets=()
tot_w=0
tot_h=0

for i in src_mp4/* ; do
 name=$(basename ${i%.*})
 case $name in
 tile_*)
  if [[ $name =~ _([[:digit:]]+)_([[:digit:]]+)_([[:digit:]]+)_([[:digit:]]+) ]]; then
    x=${BASH_REMATCH[1]}
    y=${BASH_REMATCH[2]}
    w=${BASH_REMATCH[3]}
    h=${BASH_REMATCH[4]}
    tmw=$(( ${x} + ${w} ))
    tmh=$(( ${y} + ${h} ))

    if (( tmw > tot_w )) ; then
     tot_w=$tmw
    fi 
    if (( tmh > tot_h )) ; then
     tot_h=$tmh
    fi 
    
  fi
  ;;
  *)
  ;;
 esac
done

echo "grid size $tot_w $tot_h"


for i in src_mp4/* ; do
 name=$(basename ${i%.*})
 case $name in
 tile_*)
  if [[ $name =~ _([[:digit:]]+)_([[:digit:]]+)_([[:digit:]]+)_([[:digit:]]+) ]]; then
    x=${BASH_REMATCH[1]}
    y=${BASH_REMATCH[2]}
    w=${BASH_REMATCH[3]}
    h=${BASH_REMATCH[4]}
    srd_value="0,$x,$y,$w,$h,$tot_w,$tot_h"    
  fi
  ;;
  *)
   srd_value="0,0,0,$tot_w,$tot_h,$tot_w,$tot_h"    
  ;;
 esac
 echo "srd val $srd_value"
 DESC=":desc_as=<SupplementalProperty schemeIdUri="\""urn:mpeg:dash:srd:2014"\"" value="\""$srd_value"\""/>"
 sets+=(""../$i"$DESC")

done

cd $out_dir
#echo "set elements: " ${#sets[@]}
#echo "set is " "${sets[@]}"
MP4Box -logs all@info -dash 1000 -profile live -bs-switching no -out live360.mpd "${sets[@]}"

cd ..

}


generate_files
generate_dash
